# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/clients/type_document.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ev1/clients/type_document.proto\x12)pro.omni.oms.api.v1.clients.type_document\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xe1\x01\n\x0cTypeDocument\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12*\n\x06is_vat\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1c\n\x14\x64ocument_type_doc_id\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xb9\x01\n\x19TypeDocumentCreateRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1c\n\x14\x64ocument_type_doc_id\x18\x03 \x01(\t\x12*\n\x06is_vat\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb7\x01\n\x1aTypeDocumentCreateResponse\x12N\n\rtype_document\x18\x01 \x01(\x0b\x32\x37.pro.omni.oms.api.v1.clients.type_document.TypeDocument\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf5\x02\n\x17TypeDocumentReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf1\x01\n\x18TypeDocumentReadResponse\x12O\n\x0etype_documents\x18\x01 \x03(\x0b\x32\x37.pro.omni.oms.api.v1.clients.type_document.TypeDocument\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData"\xa3\x01\n\x19TypeDocumentUpdateRequest\x12N\n\rtype_document\x18\x01 \x01(\x0b\x32\x37.pro.omni.oms.api.v1.clients.type_document.TypeDocument\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb7\x01\n\x1aTypeDocumentUpdateResponse\x12N\n\rtype_document\x18\x01 \x01(\x0b\x32\x37.pro.omni.oms.api.v1.clients.type_document.TypeDocument\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"_\n\x19TypeDocumentDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"g\n\x1aTypeDocumentDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xa7\x05\n\x13TypeDocumentService\x12\xa3\x01\n\x12TypeDocumentCreate\x12\x44.pro.omni.oms.api.v1.clients.type_document.TypeDocumentCreateRequest\x1a\x45.pro.omni.oms.api.v1.clients.type_document.TypeDocumentCreateResponse"\x00\x12\x9d\x01\n\x10TypeDocumentRead\x12\x42.pro.omni.oms.api.v1.clients.type_document.TypeDocumentReadRequest\x1a\x43.pro.omni.oms.api.v1.clients.type_document.TypeDocumentReadResponse"\x00\x12\xa3\x01\n\x12TypeDocumentUpdate\x12\x44.pro.omni.oms.api.v1.clients.type_document.TypeDocumentUpdateRequest\x1a\x45.pro.omni.oms.api.v1.clients.type_document.TypeDocumentUpdateResponse"\x00\x12\xa3\x01\n\x12TypeDocumentDelete\x12\x44.pro.omni.oms.api.v1.clients.type_document.TypeDocumentDeleteRequest\x1a\x45.pro.omni.oms.api.v1.clients.type_document.TypeDocumentDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.clients.type_document_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _globals["_TYPEDOCUMENT"]._serialized_start = 129
    _globals["_TYPEDOCUMENT"]._serialized_end = 354
    _globals["_TYPEDOCUMENTCREATEREQUEST"]._serialized_start = 357
    _globals["_TYPEDOCUMENTCREATEREQUEST"]._serialized_end = 542
    _globals["_TYPEDOCUMENTCREATERESPONSE"]._serialized_start = 545
    _globals["_TYPEDOCUMENTCREATERESPONSE"]._serialized_end = 728
    _globals["_TYPEDOCUMENTREADREQUEST"]._serialized_start = 731
    _globals["_TYPEDOCUMENTREADREQUEST"]._serialized_end = 1104
    _globals["_TYPEDOCUMENTREADRESPONSE"]._serialized_start = 1107
    _globals["_TYPEDOCUMENTREADRESPONSE"]._serialized_end = 1348
    _globals["_TYPEDOCUMENTUPDATEREQUEST"]._serialized_start = 1351
    _globals["_TYPEDOCUMENTUPDATEREQUEST"]._serialized_end = 1514
    _globals["_TYPEDOCUMENTUPDATERESPONSE"]._serialized_start = 1517
    _globals["_TYPEDOCUMENTUPDATERESPONSE"]._serialized_end = 1700
    _globals["_TYPEDOCUMENTDELETEREQUEST"]._serialized_start = 1702
    _globals["_TYPEDOCUMENTDELETEREQUEST"]._serialized_end = 1797
    _globals["_TYPEDOCUMENTDELETERESPONSE"]._serialized_start = 1799
    _globals["_TYPEDOCUMENTDELETERESPONSE"]._serialized_end = 1902
    _globals["_TYPEDOCUMENTSERVICE"]._serialized_start = 1905
    _globals["_TYPEDOCUMENTSERVICE"]._serialized_end = 2584
# @@protoc_insertion_point(module_scope)
